@@ -1,7 +1,7 @@
 # coding: utf-8
 #
 #    Project: Azimuthal integration
-#             https://github.com/pyFAI/pyFAI
+#             https://github.com/silx-kit/pyFAI
 #
 #    Copyright (C) 2015 European Synchrotron Radiation Facility, Grenoble, France
 #
@@ -32,12 +32,12 @@ __author__ = "Jerome Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "18/12/2015"
+__date__ = "24/11/2016"
 __status__ = "development"
 __docformat__ = 'restructuredtext'
 __doc__ = """
 
-Module with GUI for diffraction mapping experiments 
+Module with GUI for diffraction mapping experiments
 
 
 """
@@ -45,24 +45,23 @@ import os
 import time
 import json
 import threading
-import numpy
-from .gui_utils import QtGui, QtCore, Signal, uic, pyplot, update_fig
-from .utils import float_, int_, str_, get_ui_file
-from .decorators import timeit
+from .gui import qt
+from .gui.matplotlib import pyplot
+from .utils import int_, str_, get_ui_file
 from .units import to_unit
 from .integrate_widget import AIWidget
 from . import worker
 from .diffmap import DiffMap
 from .tree import ListDataSet, DataSet
 import logging
-logger = logging.getLogger("pyFAI.diffmap_widget")
+logger = logging.getLogger(__name__)
 
 
-class IntegrateWidget(QtGui.QDialog):
+class IntegrateWidget(qt.QDialog):
     def __init__(self, parent=None):
-        QtGui.QDialog.__init__(self)
+        qt.QDialog.__init__(self)
         self.widget = AIWidget()
-        self.layout = QtGui.QGridLayout(self)
+        self.layout = qt.QGridLayout(self)
         self.layout.addWidget(self.widget)
         self.widget.okButton.clicked.disconnect()
         self.widget.do_2D.setEnabled(False)
@@ -76,14 +75,13 @@ class IntegrateWidget(QtGui.QDialog):
         return res
 
 
-class TreeModel(QtCore.QAbstractItemModel):
+class TreeModel(qt.QAbstractItemModel):
     def __init__(self, win, root_item):
         super(TreeModel, self).__init__(win)
         self._root_item = root_item
         self._win = win
         self._current_branch = None
 
-    @timeit
     def update(self, new_root):
         self.beginResetModel()
         new_labels = [i.label for i in new_root.children]
@@ -110,8 +108,8 @@ class TreeModel(QtCore.QAbstractItemModel):
         return 1
 
     def flags(self, midx):
-#        if midx.column()==1:
-        return QtCore.Qt.ItemIsEnabled
+        # if midx.column()==1:
+        return qt.Qt.ItemIsEnabled
 
     def index(self, row, column, parent):
         pitem = parent.internalPointer()
@@ -120,7 +118,7 @@ class TreeModel(QtCore.QAbstractItemModel):
         try:
             item = pitem.children[row]
         except IndexError:
-            return QtCore.QModelIndex()
+            return qt.QModelIndex()
         return self.createIndex(row, column, item)
 
     def data(self, midx, role):
@@ -128,11 +126,11 @@ class TreeModel(QtCore.QAbstractItemModel):
         What to display depending on model_index and role
         """
         leaf = midx.internalPointer()
-        if midx.column() == 0 and role == QtCore.Qt.DisplayRole:
+        if midx.column() == 0 and role == qt.Qt.DisplayRole:
             return leaf.label
 
     def headerData(self, section, orientation, role):
-        if role == QtCore.Qt.DisplayRole and orientation == QtCore.Qt.Horizontal:
+        if role == qt.Qt.DisplayRole and orientation == qt.Qt.Horizontal:
             # return ["Path", "shape"][section]
             return ["Path"][section]
 
@@ -143,34 +141,35 @@ class TreeModel(QtCore.QAbstractItemModel):
             return  # QtCore.QModelIndex()
         pitem = item.parent
         if pitem is self._root_item:
-            return QtCore.QModelIndex()
+            return qt.QModelIndex()
         row_idx = pitem.parent.children.index(pitem)
         return self.createIndex(row_idx, 0, pitem)
 
 
-class DiffMapWidget(QtGui.QWidget):
-    progressbarChanged = Signal(int, int)
+class DiffMapWidget(qt.QWidget):
+    progressbarChanged = qt.Signal(int, int)
 #     progressbarAborted = Signal()
     uif = "diffmap.ui"
     json_file = ".diffmap.json"
     URL = "http://pyfai.readthedocs.org/en/latest/man/scripts.html"
+
     def __init__(self):
-        QtGui.QWidget.__init__(self)
+        qt.QWidget.__init__(self)
 
         self.integration_config = {}
         self.list_dataset = ListDataSet()  # Contains all datasets to be treated.
 
         try:
-            uic.loadUi(get_ui_file(self.uif), self)
-        except AttributeError as error:
+            qt.loadUi(get_ui_file(self.uif), self)
+        except AttributeError as _error:
             logger.error("I looks like your installation suffers from this bug: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=697348")
             raise RuntimeError("Please upgrade your installation of PyQt (or apply the patch)")
         self.aborted = False
         self.progressBar.setValue(0)
         self.list_model = TreeModel(self, self.list_dataset.as_tree())
         self.listFiles.setModel(self.list_model)
-        self.listFiles.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
-        self.listFiles.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
+        self.listFiles.setSelectionBehavior(qt.QAbstractItemView.SelectRows)
+        self.listFiles.setSelectionMode(qt.QAbstractItemView.ExtendedSelection)
         self.create_connections()
         self.set_validator()
         self.update_number_of_frames()
@@ -197,12 +196,12 @@ class DiffMapWidget(QtGui.QWidget):
         self._menu_file()
 
     def set_validator(self):
-        validator = QtGui.QIntValidator(0, 999999, self)
+        validator = qt.QIntValidator(0, 999999, self)
         self.fastMotorPts.setValidator(validator)
         self.slowMotorPts.setValidator(validator)
         self.offset.setValidator(validator)
 
-        float_valid = QtGui.QDoubleValidator(self)
+        float_valid = qt.QDoubleValidator(self)
         self.rMin.setValidator(float_valid)
         self.rMax.setValidator(float_valid)
 
@@ -220,33 +219,32 @@ class DiffMapWidget(QtGui.QWidget):
         self.progressbarChanged.connect(self.update_processing)
         self.rMin.editingFinished.connect(self.update_slice)
         self.rMax.editingFinished.connect(self.update_slice)
-#         self.listFiles.expanded.connect(lambda:self.listFiles.resizeColumnToContents(0))
+        # self.listFiles.expanded.connect(lambda:self.listFiles.resizeColumnToContents(0))
 
     def _menu_file(self):
         # Drop-down file menu
-        self.files_menu = QtGui.QMenu("Files")
+        self.files_menu = qt.QMenu("Files")
 
-        action_more = QtGui.QAction("add files", self.files)
+        action_more = qt.QAction("add files", self.files)
         self.files_menu.addAction(action_more)
         action_more.triggered.connect(self.input_filer)
 
-        action_sort = QtGui.QAction("sort files", self.files)
+        action_sort = qt.QAction("sort files", self.files)
         self.files_menu.addAction(action_sort)
         action_sort.triggered.connect(self.sort_input)
 
-        action_clear = QtGui.QAction("clear selected files", self.files)
+        action_clear = qt.QAction("clear selected files", self.files)
         self.files_menu.addAction(action_clear)
         action_clear.triggered.connect(self.clear_selection)
 
         self.files.setMenu(self.files_menu)
 
-
     def do_abort(self):
         self.aborted = True
 
     def input_filer(self, *args, **kwargs):
         """
-        Called when addFiles clicked: opens a file-brower and populates the 
+        Called when addFiles clicked: opens a file-browser and populates the
         listFiles object
         """
         filters = [
@@ -258,9 +256,9 @@ class DiffMapWidget(QtGui.QWidget):
             "CBF files (*.cbf)",
             "MarCCD image files (*.mccd)",
             "Any file (*)"]
-        fnames = QtGui.QFileDialog.getOpenFileNames(self,
+        fnames = qt.QFileDialog.getOpenFileNames(self,
                          "Select one or more diffraction image files",
-                         QtCore.QDir.currentPath(),
+                         qt.QDir.currentPath(),
                          filter=self.tr(";;".join(filters)))
         for i in fnames:
             self.list_dataset.append(DataSet(str_(i), None, None, None))
@@ -285,7 +283,7 @@ class DiffMapWidget(QtGui.QWidget):
         if self.integration_config:
             iw.widget.set_config(self.integration_config)
         res = iw.exec_()
-        if res == QtGui.QDialog.Accepted:
+        if res == qt.QDialog.Accepted:
             iw.widget.input_data = [i.path for i in self.list_dataset]
             self.integration_config = iw.get_config()
         print(json.dumps(self.integration_config, indent=2))
@@ -294,23 +292,25 @@ class DiffMapWidget(QtGui.QWidget):
         """
         called when clicking on "outputFileSelector"
         """
-        fname = QtGui.QFileDialog.getSaveFileName(self, "Output file",
-                                                  QtCore.QDir.currentPath(),
-                                                  filter=self.tr("NeXuS file (*.nxs);;HDF5 file (*.h5);;HDF5 file (*.hdf5)"))
+        fname = qt.QFileDialog.getSaveFileName(self, "Output file",
+                                               qt.QDir.currentPath(),
+                                               filter=self.tr("NeXuS file (*.nxs);;HDF5 file (*.h5);;HDF5 file (*.hdf5)"))
         self.outputFile.setText(fname)
 
     def start_processing(self, *arg, **kwarg):
         logger.info("in start_processing")
         if not self.integration_config:
-            result = QtGui.QMessageBox.warning(self, "Azimuthal Integration",
-                                                   "You need to configure first the Azimuthal integration")
+            result = qt.QMessageBox.warning(self,
+                                            "Azimuthal Integration",
+                                            "You need to configure first the Azimuthal integration")
             if result:
                 self.configure_diffraction()
             else:
                 return
         if not str(self.outputFile.text()):
-            result = QtGui.QMessageBox.warning(self, "Destination",
-                                                   "You need to configure first the destination file")
+            result = qt.QMessageBox.warning(self,
+                                            "Destination",
+                                            "You need to configure first the destination file")
             if result:
                 self.configure_output()
             else:
@@ -347,10 +347,9 @@ class DiffMapWidget(QtGui.QWidget):
         self.list_model.update(self.list_dataset.as_tree())
 
     def get_config(self):
-        """Return a dict with the plugin configuration which is JSON-serializable 
+        """Return a dict with the plugin configuration which is JSON-serializable
         """
-        res = {
-               "ai": self.integration_config,
+        res = {"ai": self.integration_config,
                "experiment_title": str_(self.experimentTitle.text()).strip(),
                "fast_motor_name": str_(self.fastMotorName.text()).strip(),
                "slow_motor_name": str_(self.slowMotorName.text()).strip(),
@@ -364,19 +363,19 @@ class DiffMapWidget(QtGui.QWidget):
 
     def set_config(self, dico):
         """Set up the widget from dictionary
-        
-        @param  dico: dictionary 
+
+        :param  dico: dictionary
         """
         self.integration_config = dico.get("ai", {})
         # TODO
         setup_data = {"experiment_title": self.experimentTitle.setText,
                       "fast_motor_name": self.fastMotorName.setText,
-                      "slow_motor_name":self.slowMotorName.setText,
-                      "fast_motor_points":lambda a:self.fastMotorPts.setText(str_(a)),
-                      "slow_motor_points":lambda a:self.slowMotorPts.setText(str_(a)),
-                      "offset":lambda a:self.offset.setText(str_(a)),
-                      "output_file":self.outputFile.setText
-                   }
+                      "slow_motor_name": self.slowMotorName.setText,
+                      "fast_motor_points": lambda a: self.fastMotorPts.setText(str_(a)),
+                      "slow_motor_points": lambda a: self.slowMotorPts.setText(str_(a)),
+                      "offset": lambda a: self.offset.setText(str_(a)),
+                      "output_file": self.outputFile.setText
+                      }
         for key, value in setup_data.items():
             if key in dico:
                 value(dico[key])
@@ -388,8 +387,8 @@ class DiffMapWidget(QtGui.QWidget):
 
     def dump(self, fname=None):
         """Save the configuration in a JSON file
-        
-        @param fname: file where the config is saved as JSON 
+
+        :param fname: file where the config is saved as JSON
         """
         if fname is None:
             fname = self.json_file
@@ -400,13 +399,13 @@ class DiffMapWidget(QtGui.QWidget):
 
     def restore(self, fname=None):
         """Restore the widget from saved config
-        
-        @param fname: file where the config is saved as JSON
+
+        :param fname: file where the config is saved as JSON
         """
         if fname is None:
             fname = self.json_file
         if not os.path.exists(fname):
-            logger.warning("No such configuration file: %s" % fname)
+            logger.warning("No such configuration file: %s", fname)
             return
         with open(fname, "r") as fd:
             dico = json.loads(fd.read())
@@ -414,15 +413,15 @@ class DiffMapWidget(QtGui.QWidget):
 
     def save_config(self):
         logger.debug("save_config")
-        json_file = str_(QtGui.QFileDialog.getSaveFileName(caption="Save configuration as json",
-                                                           directory=self.json_file,
-                                                           filter="Config (*.json)"))
+        json_file = str_(qt.QFileDialog.getSaveFileName(caption="Save configuration as json",
+                                                        directory=self.json_file,
+                                                        filter="Config (*.json)"))
         if json_file:
             self.dump(json_file)
 
     def process(self, config=None):
         """
-        Called in a separate thread 
+        Called in a separate thread
         """
         logger.info("process")
         t0 = time.time()
@@ -437,6 +436,7 @@ class DiffMapWidget(QtGui.QWidget):
             print(config_ai)
             diffmap.ai = worker.make_ai(config_ai)
             diffmap.method = config_ai.get("method", "csr")
+            diffmap.unit = to_unit(config_ai.get("unit", "2th_deg"))
             diffmap.hdf5 = config.get("output_file", "unamed.h5")
             self.radial_data = diffmap.init_ai()
             self.data_h5 = diffmap.dataset
@@ -453,13 +453,13 @@ class DiffMapWidget(QtGui.QWidget):
             if diffmap.nxs:
                 self.data_np = diffmap.dataset.value
                 diffmap.nxs.close()
-        logger.warning("Processing finished in %.3fs" % (time.time() - t0))
+        logger.warning("Processing finished in %.3fs", time.time() - t0)
         self.progressbarChanged.emit(len(self.list_dataset), 0)
 
     def display_processing(self, config):
         """Setup the display for visualizing the processing
-        
-        @param config: configuration of the processing ongoing
+
+        :param config: configuration of the processing ongoing
         """
         self.fig = pyplot.figure(figsize=(12, 5))
         self.aximg = self.fig.add_subplot(1, 2, 1,
@@ -476,10 +476,10 @@ class DiffMapWidget(QtGui.QWidget):
         self.fig.show()
 
     def update_processing(self, idx_file, idx_img):
-        """ Update the process bar and the images 
-        
-        @param idx_file: file number
-        @parm idx_img: frame number
+        """ Update the process bar and the images
+
+        :param idx_file: file number
+        :param idx_img: frame number
         """
         if idx_file >= 0:
             self.progressBar.setValue(idx_file)
@@ -508,7 +508,7 @@ class DiffMapWidget(QtGui.QWidget):
                 self.img.set_data(img)
             self.last_idx = idx_img
             self.fig.canvas.draw()
-            QtCore.QCoreApplication.processEvents()
+            qt.QCoreApplication.processEvents()
             time.sleep(0.1)
 
     def update_slice(self, *args):
@@ -530,4 +530,3 @@ class DiffMapWidget(QtGui.QWidget):
         stop = (self.radial_data <= qmax).sum()
         self.slice = slice(start, stop)
         self.update_processing(-1, self.last_idx)
-
