@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #    Project: Azimuthal integration
-#             https://github.com/pyFAI/pyFAI
+#             https://github.com/silx-kit/pyFAI
 #
 #    Copyright 2013-2016 (C) European Synchrotron Radiation Facility, Grenoble, France
 #
@@ -30,7 +30,7 @@ __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "13/05/2016"
+__date__ = "25/11/2016"
 __status__ = "development"
 
 import logging
@@ -38,7 +38,6 @@ import threading
 import os
 import numpy
 logger = logging.getLogger("pyFAI.distortion")
-logging.basicConfig(level=logging.INFO)
 from math import ceil, floor
 from . import detectors
 from .opencl import ocl
@@ -46,17 +45,29 @@ if ocl:
     from . import ocl_azim_lut, ocl_azim_csr
 else:
     ocl_azim_lut = ocl_azim_csr = None
-from .decorators import timeit
 try:
     from .third_party import six
 except ImportError:
     import six
 try:
     from .ext import _distortion
+    from .ext import sparse_utils
 except ImportError:
     logger.warning("Import _distortion cython implementation failed ... pure python version is terribly slow !!!")
     _distortion = None
 
+try:
+    from scipy.sparse import linalg, csr_matrix
+except IOError:
+    logger.warning("Scipy is missing ... uncorrection will be handled the old way")
+    linalg = None
+else:
+    import scipy
+    v = tuple(int(i) for i in scipy.version.short_version.split("."))
+    if v < (0, 11):
+        logger.warning("Scipy is too old ... uncorrection will be handled the old way")
+        linalg = None
+
 
 class Distortion(object):
     """
@@ -65,15 +76,15 @@ class Distortion(object):
     New version compatible both with CSR and LUT...
     """
     def __init__(self, detector="detector", shape=None, resize=False, empty=0,
-                 mask=None, method="LUT", device=None, workgroup=8):
+                 mask=None, method="CSR", device=None, workgroup=8):
         """
-        @param detector: detector instance or detector name
-        @param shape: shape of the output image
-        @param resize: allow the output shape to be different from the input shape
-        @param empty: value to be given for empty bins
-        @param method: "lut" or "csr", the former is faster
-        @param device: Name of the device: None for OpenMP, "cpu" or "gpu" or the id of the OpenCL device a 2-tuple of integer
-        @param workgroup: workgroup size for CSR on OpenCL
+        :param detector: detector instance or detector name
+        :param shape: shape of the output image
+        :param resize: allow the output shape to be different from the input shape
+        :param empty: value to be given for empty bins
+        :param method: "lut" or "csr", the former is faster
+        :param device: Name of the device: None for OpenMP, "cpu" or "gpu" or the id of the OpenCL device a 2-tuple of integer
+        :param workgroup: workgroup size for CSR on OpenCL
         """
         self._shape_out = None
         if isinstance(detector, six.string_types):
@@ -121,10 +132,10 @@ class Distortion(object):
         """
         reset the distortion correction and re-calculate the look-up table
 
-        @param method: can be "lut" or "csr", "lut" looks faster
-        @param device: can be None, "cpu" or "gpu" or the id as a 2-tuple of integer
-        @param worgroup: enforce the workgroup size for CSR.
-        @param prepare: set to false to only reset and not re-initialize
+        :param method: can be "lut" or "csr", "lut" looks faster
+        :param device: can be None, "cpu" or "gpu" or the id as a 2-tuple of integer
+        :param worgroup: enforce the workgroup size for CSR.
+        :param prepare: set to false to only reset and not re-initialize
         """
         with self._sem:
             self.max_size = None
@@ -147,7 +158,7 @@ class Distortion(object):
         """
         Calculate/cache the output shape
 
-        @return output shape
+        :return output shape
         """
         if self._shape_out is None:
             self.calc_pos()
@@ -156,8 +167,8 @@ class Distortion(object):
     def calc_pos(self, use_cython=True):
         """Calculate the pixel boundary position on the regular grid
 
-        @return: pixel corner positions (in pixel units) on the regular grid
-        @rtyep: ndarray of shape (nrow, ncol, 4, 2)
+        :return: pixel corner positions (in pixel units) on the regular grid
+        :rtype: ndarray of shape (nrow, ncol, 4, 2)
         """
         if self.delta1 is None:
             with self._sem:
@@ -191,7 +202,7 @@ class Distortion(object):
     def calc_size(self, use_cython=True):
         """Calculate the number of pixels falling into every single bin and
 
-        @return: max of pixel falling into a single bin
+        :return: max of pixel falling into a single bin
 
         Considering the "half-CCD" spline from ID11 which describes a (1025,2048) detector,
         the physical location of pixels should go from:
@@ -252,11 +263,10 @@ class Distortion(object):
                                                                       platformid=self.device[0], deviceid=self.device[1],
                                                                       block_size=self.workgroup)
 
-#     @timeit
     def calc_LUT(self, use_common=True):
-        """Calculate the Look-up table 
-        
-        @return: look up table either in CSR or LUT format depending on serl.method
+        """Calculate the Look-up table
+
+        :return: look up table either in CSR or LUT format depending on serl.method
         """
         if self.pos is None:
             self.calc_pos()
@@ -324,15 +334,13 @@ class Distortion(object):
         """
         Correct an image based on the look-up table calculated ...
 
-        @param image: 2D-array with the image
-        @param dummy: value suggested for bad pixels
-        @param delta_dummy: precision of the dummy value
-        @return: corrected 2D image
-
-        #TODO: #225
+        :param image: 2D-array with the image
+        :param dummy: value suggested for bad pixels
+        :param delta_dummy: precision of the dummy value
+        :return: corrected 2D image
         """
         if image.shape != self.shape_in:
-            logger.error("The image shape (%s) is not the same as the detector (%s). Adapting shape ..." % (image.shape, self.shape_in))
+            logger.error("The image shape (%s) is not the same as the detector (%s). Adapting shape ...", image.shape, self.shape_in)
             new_img = numpy.zeros(self.shape_in, dtype=image.dtype)
             common_shape = [min(i, j) for i, j in zip(image.shape, self.shape_in)]
             new_img[:common_shape[0], :common_shape[1]] = image[:common_shape[0], :common_shape[1]]
@@ -364,75 +372,61 @@ class Distortion(object):
         try:
             out.shape = self._shape_out
         except ValueError as _err:
-            logger.error("Requested in_shape=%s out_shape=%s and " % (self.shape_in, self.shape_out))
+            logger.error("Requested in_shape=%s out_shape=%s and ", self.shape_in, self.shape_out)
             raise
         return out
 
-    def uncorrect(self, image):
+    def uncorrect(self, image, use_cython=False):
         """
         Take an image which has been corrected and transform it into it's raw (with loss of information)
 
-        @param image: 2D-array with the image
-        @return: uncorrected 2D image and a mask (pixels in raw image
+        :param image: 2D-array with the image
+        :return: uncorrected 2D image
+
+        Nota: to retrieve the input mask on can do:
+
+        >>> msk =  dis.uncorrect(numpy.ones(dis._shape_out)) <= 0
         """
+        assert image.shape == self._shape_out
         if self.lut is None:
             self.calc_LUT()
-        if self.method == "lut":
-            if _distortion is not None:
-                out, mask = _distortion.uncorrect_LUT(image, self._shape_out, self.lut)
+        if (linalg is not None) and (use_cython is False):
+            if self.method == "lut":
+                csr = csr_matrix(sparse_utils.LUT_to_CSR(self.lut))
             else:
-                out = numpy.zeros(self._shape_out, dtype=numpy.float32)
-                mask = numpy.zeros(self._shape_out, dtype=numpy.int8)
-                lmask = mask.ravel()
-                lout = out.ravel()
-                lin = image.ravel()
-                tot = self.lut.coef.sum(axis=-1)
-                for idx in range(self.lut.shape[0]):
-                    t = tot[idx]
-                    if t <= 0:
-                        lmask[idx] = 1
-                        continue
-                    val = lin[idx] / t
-                    lout[self.lut[idx].idx] += val * self.lut[idx].coef
-        elif self.method == "csr":
-            if _distortion is not None:
-                out = _distortion.uncorrect_CSR(image, self._shape_out, self.lut)
+                csr = csr_matrix(self.lut)
+            res = linalg.lsmr(csr, image.ravel())
+            out = res[0].reshape(self.shape_in)
+        else:  # This is deprecated and does not work with resise=True
+            if self.method == "lut":
+                if _distortion is not None:
+                    out, mask = _distortion.uncorrect_LUT(image, self.shape_in, self.lut)
+                else:
+                    out = numpy.zeros(self.shape_in, dtype=numpy.float32)
+                    lout = out.ravel()
+                    lin = image.ravel()
+                    tot = self.lut.coef.sum(axis=-1)
+                    for idx in range(self.lut.shape[0]):
+                        t = tot[idx]
+                        if t <= 0:
+                            continue
+                        val = lin[idx] / t
+                        lout[self.lut[idx].idx] += val * self.lut[idx].coef
+            elif self.method == "csr":
+                if _distortion is not None:
+                    out, mask = _distortion.uncorrect_CSR(image, self.shape_in, self.lut)
             else:
                 raise NotImplementedError()
-        return out, mask
+        return out
 
 
 class Quad(object):
     """
+    Quad modelisation.
 
-                                     |
-                                     |
-                                     |                       xxxxxA
-                                     |      xxxxxxxI'xxxxxxxx     x
-                             xxxxxxxxIxxxxxx       |               x
-                Bxxxxxxxxxxxx        |             |               x
-                x                    |             |               x
-                x                    |             |               x
-                 x                   |             |                x
-                 x                   |             |                x
-                 x                   |             |                x
-                 x                   |             |                x
-                 x                   |             |                x
-                  x                  |             |                 x
-                  x                  |             |                 x
-                  x                  |             |                 x
-                  x                 O|             P              A'  x
- -----------------J------------------+--------------------------------L-----------------------
-                  x                  |                                 x
-                  x                  |                                  x
-                  x                  |                                  x
-                   x                 |     xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxD
-                   CxxxxxxxxxxxxxxxxxKxxxxx
-                                     |
-                                     |
-                                     |
-                                     |
-        """
+    .. image:: ../img/quad_model.svg
+        :alt: Modelization of the quad
+    """
     def __init__(self, buffer):
         self.box = buffer
         self.A0 = self.A1 = None
@@ -699,7 +693,7 @@ class Quad(object):
                             if dA > AA:
                                 dA = AA
                                 AA = -1
-                            self.box[i - 1 , h] += sign * dA
+                            self.box[i - 1, h] += sign * dA
                             AA -= dA
                             h += 1
                 # Section Pn->B
@@ -803,7 +797,7 @@ def test():
 #    dis.calc_LUT()
 #    out = dis.correct(grid)
 #    fabio.edfimage.edfimage(data=out.astype("float32")).write("test2048.edf")
-    from .gui_utils import pylab
+    from .gui.matplotlib import pylab
     pylab.imshow(out)  # , interpolation="nearest")
     pylab.show()
 
