@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #    Project: Azimuthal integration
-#             https://github.com/pyFAI
+#             https://github.com/silx-kit
 #
 #
 #    Copyright (C) European Synchrotron Radiation Facility, Grenoble, France
@@ -25,7 +25,7 @@
 
 __authors__ = ["Jérôme Kieffer", "Giannis Ashiotis"]
 __license__ = "GPLv3"
-__date__ = "11/04/2016"
+__date__ = "24/11/2016"
 __copyright__ = "2014, ESRF, Grenoble"
 __contact__ = "jerome.kieffer@esrf.fr"
 
@@ -49,20 +49,20 @@ class OCL_CSR_Integrator(object):
                  checksum=None, profile=False,
                  empty=None):
         """
-        @param lut: 3-tuple of arrays
+        :param lut: 3-tuple of arrays
             data: coefficient of the matrix in a 1D vector of float32 - size of nnz
             indices: Column index position for the data (same size as data)
             indptr: row pointer indicates the start of a given row. len nbin+1
-        @param image_size: size of the image (for pre-processing)
-        @param devicetype: can be "cpu","gpu","acc" or "all"
-        @param block_size: the chosen size for WORKGROUP_SIZE
-        @param platformid: number of the platform as given by clinfo
-        @type platformid: int
-        @param deviceid: number of the device as given by clinfo
-        @type deviceid: int
-        @param checksum: pre - calculated checksum to prevent re - calculating it :)
-        @param profile: store profiling elements
-        @param empty: value to be assigned to bins without contribution from any pixel
+        :param image_size: size of the image (for pre-processing)
+        :param devicetype: can be "cpu","gpu","acc" or "all"
+        :param block_size: the chosen size for WORKGROUP_SIZE
+        :param platformid: number of the platform as given by clinfo
+        :type platformid: int
+        :param deviceid: number of the device as given by clinfo
+        :type deviceid: int
+        :param checksum: pre - calculated checksum to prevent re - calculating it :)
+        :param profile: store profiling elements
+        :param empty: value to be assigned to bins without contribution from any pixel
         """
         self._sem = threading.Semaphore()
         self._data = lut[0]
@@ -92,7 +92,7 @@ class OCL_CSR_Integrator(object):
             if res:
                 platformid, deviceid = res
             else:
-                logger.warning("No such devicetype %s" % devicetype)
+                logger.warning("No such devicetype %s", devicetype)
                 platformid, deviceid = ocl.select_device()
         elif platformid is None:
             platformid = 0
@@ -137,7 +137,7 @@ class OCL_CSR_Integrator(object):
 
     def __copy__(self):
         """Shallow copy of the object
-        
+
         :return: copy of the object
         """
         return self.__class__((self._data, self._indices, self._indptr),
@@ -149,7 +149,7 @@ class OCL_CSR_Integrator(object):
 
     def __deepcopy__(self, memo=None):
         """deep copy of the object
-        
+
         :return: deepcopy of the object
         """
         if memo is None:
@@ -158,7 +158,7 @@ class OCL_CSR_Integrator(object):
         memo[id(self._data)] = new_csr[0]
         memo[id(self._indices)] = new_csr[1]
         memo[id(self._indptr)] = new_csr[2]
-        new_obj = self.__class__(new_csr, self.size, 
+        new_obj = self.__class__(new_csr, self.size,
                                  block_size=self.BLOCK_SIZE,
                                  platformid=self.platform.id,
                                  deviceid=self.device.id,
@@ -208,7 +208,7 @@ class OCL_CSR_Integrator(object):
     def _compile_kernels(self, kernel_file=None):
         """
         Call the OpenCL compiler
-        @param kernel_file: path to the kernel (by default use the one in the src directory)
+        :param kernel_file: path to the kernel (by default use the one in the src directory)
         """
         # concatenate all needed source files into a single openCL module
         kernel_file = kernel_file or "ocl_azim_CSR.cl"
@@ -216,7 +216,7 @@ class OCL_CSR_Integrator(object):
 
         compile_options = "-D NBINS=%i  -D NIMAGE=%i -D WORKGROUP_SIZE=%i -D ON_CPU=%i" % \
                 (self.bins, self.size, self.BLOCK_SIZE, int(self.device_type == "CPU"))
-        logger.info("Compiling file %s with options %s" % (kernel_file, compile_options))
+        logger.info("Compiling file %s with options %s", kernel_file, compile_options)
         try:
             self._program = pyopencl.Program(self.ctx, kernel_src).build(options=compile_options)
         except (pyopencl.MemoryError, pyopencl.LogicError) as error:
@@ -253,29 +253,30 @@ class OCL_CSR_Integrator(object):
         self._cl_kernel_args["u32_to_float"] = [self._cl_mem[i] for i in ["image_raw", "image"]]
         self._cl_kernel_args["s32_to_float"] = [self._cl_mem[i] for i in ["image_raw", "image"]]
 
-
     def integrate(self, data, dummy=None, delta_dummy=None, dark=None, flat=None, solidAngle=None, polarization=None,
                             dark_checksum=None, flat_checksum=None, solidAngle_checksum=None, polarization_checksum=None,
                             preprocess_only=False, safe=True, normalization_factor=1.0):
         """
-        Before performing azimuthal integration, the preprocessing is :
+        Before performing azimuthal integration, the preprocessing is:
 
-        data = (data - dark) / (flat*solidAngle*polarization)
+        .. math::
+
+            data = (data - dark) / (flat * solidAngle * polarization)
 
         Integration is performed using the CSR representation of the look-up table
 
-        @param dark: array of same shape as data for pre-processing
-        @param flat: array of same shape as data for pre-processing
-        @param solidAngle: array of same shape as data for pre-processing
-        @param polarization: array of same shape as data for pre-processing
-        @param dark_checksum: CRC32 checksum of the given array
-        @param flat_checksum: CRC32 checksum of the given array
-        @param solidAngle_checksum: CRC32 checksum of the given array
-        @param polarization_checksum: CRC32 checksum of the given array
-        @param safe: if True (default) compares arrays on GPU according to their checksum, unless, use the buffer location is used
-        @param preprocess_only: return the dark subtracted; flat field & solidAngle & polarization corrected image, else
-        @param normalization_factor: divide result by this value
-        @return averaged data, weighted histogram, unweighted histogram
+        :param dark: array of same shape as data for pre-processing
+        :param flat: array of same shape as data for pre-processing
+        :param solidAngle: array of same shape as data for pre-processing
+        :param polarization: array of same shape as data for pre-processing
+        :param dark_checksum: CRC32 checksum of the given array
+        :param flat_checksum: CRC32 checksum of the given array
+        :param solidAngle_checksum: CRC32 checksum of the given array
+        :param polarization_checksum: CRC32 checksum of the given array
+        :param safe: if True (default) compares arrays on GPU according to their checksum, unless, use the buffer location is used
+        :param preprocess_only: return the dark subtracted; flat field & solidAngle & polarization corrected image, else
+        :param normalization_factor: divide result by this value
+        :return: averaged data, weighted histogram, unweighted histogram
         """
         events = []
         with self._sem:
@@ -312,7 +313,7 @@ class OCL_CSR_Integrator(object):
             if dummy is not None:
                 do_dummy = numpy.int32(1)
                 dummy = numpy.float32(dummy)
-                if delta_dummy == None:
+                if delta_dummy is None:
                     delta_dummy = numpy.float32(0.0)
                 else:
                     delta_dummy = numpy.float32(abs(delta_dummy))
@@ -414,6 +415,5 @@ class OCL_CSR_Integrator(object):
                     print("%50s:\t%.3fms" % (e[0], et))
                     t += et
 
-        print("_"*80)
+        print("_" * 80)
         print("%50s:\t%.3fms" % ("Total execution time", t))
-
