@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #    Project: Azimuthal integration
-#             https://github.com/pyFAI/pyFAI
+#             https://github.com/silx-kit/pyFAI
 #
 #    Copyright (C) European Synchrotron Radiation Facility, Grenoble, France
 #
@@ -27,7 +27,7 @@ __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "GPLv3+"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "04/02/2016"
+__date__ = "27/10/2016"
 __status__ = "production"
 
 import os
@@ -39,12 +39,17 @@ import types
 import array
 import operator
 import numpy
+
 try:
-    from . import gui_utils
-except ImportError:  # mainly for tests
-    gui_utils = None
-if gui_utils and gui_utils.has_Qt:
-    from .gui_utils import update_fig, maximize_fig, QtGui, matplotlib, pyplot, pylab
+    from .gui import qt
+except ImportError:
+    qt = None
+
+if qt is not None:
+    from .gui.utils import update_fig, maximize_fig
+    from .gui.matplotlib import matplotlib, pyplot, pylab
+    from .gui import utils as gui_utils
+
 import fabio
 from .calibrant import Calibrant, ALL_CALIBRANTS
 from .blob_detection import BlobDetection
@@ -85,10 +90,10 @@ class PeakPicker(object):
                  pointfile=None, calibrant=None, wavelength=None, detector=None,
                  method="massif"):
         """
-        @param data: input image as numpy array
-        @param reconst: shall masked part or negative values be reconstructed (wipe out problems with pilatus gaps)
-        @param mask: area in which keypoints will not be considered as valid
-        @param pointfile:
+        :param data: input image as numpy array
+        :param reconst: shall masked part or negative values be reconstructed (wipe out problems with pilatus gaps)
+        :param mask: area in which keypoints will not be considered as valid
+        :param pointfile:
         """
         if isinstance(data, six.string_types):
             self.data = fabio.open(data).data.astype("float32")
@@ -129,7 +134,7 @@ class PeakPicker(object):
         self.callback = None
         self.method = None
         if method not in self.VALID_METHODS:
-            logger.error("Not a valid peak-picker method: %s should be part of %s" % (method, self.VALID_METHODS))
+            logger.error("Not a valid peak-picker method: %s should be part of %s", method, self.VALID_METHODS)
             method = self.VALID_METHODS[0]
         self.init(method, False)
 
@@ -189,14 +194,14 @@ class PeakPicker(object):
         """
         Return the list of peaks within an area
 
-        @param mask: 2d array with mask.
-        @param Imin: minimum of intensity above the background to keep the point
-        @param keep: maximum number of points to keep
-        @param method: enforce the use of detection using "massif" or "blob" or "watershed"
-        @param ring: ring number to which assign the  points
-        @param dmin: minimum distance between two peaks (in pixels)
-        @param seed: good starting points.
-        @return: list of peaks [y,x], [y,x], ...]
+        :param mask: 2d array with mask.
+        :param Imin: minimum of intensity above the background to keep the point
+        :param keep: maximum number of points to keep
+        :param method: enforce the use of detection using "massif" or "blob" or "watershed"
+        :param ring: ring number to which assign the  points
+        :param dmin: minimum distance between two peaks (in pixels)
+        :param seed: good starting points.
+        :return: list of peaks [y,x], [y,x], ...]
         """
         method = kwargs.get("method")
         ring = kwargs.get("ring", 0)
@@ -239,7 +244,7 @@ class PeakPicker(object):
 
     def gui(self, log=False, maximize=False, pick=True):
         """
-        @param log: show z in log scale
+        :param log: show z in log scale
         """
         if self.fig is None:
             self.fig = pyplot.figure()
@@ -254,9 +259,9 @@ class PeakPicker(object):
             a = toolbar.addAction('Opts', self.on_option_clicked)
             a.setToolTip('open options window')
             if pick:
-                label = QtGui.QLabel("Ring #", toolbar)
+                label = qt.QLabel("Ring #", toolbar)
                 toolbar.addWidget(label)
-                self.spinbox = QtGui.QSpinBox(toolbar)
+                self.spinbox = qt.QSpinBox(toolbar)
                 self.spinbox.setMinimum(0)
                 self.sb_action = toolbar.addWidget(self.spinbox)
                 a = toolbar.addAction('Refine', self.on_refine_clicked)
@@ -288,7 +293,7 @@ class PeakPicker(object):
             s2 -= 1
             self.ax.set_xlim(0, s2)
             self.ax.set_ylim(0, s1)
-            d1 = numpy.array([0, s1, s1, 0 ])
+            d1 = numpy.array([0, s1, s1, 0])
             d2 = numpy.array([0, 0, s2, s2])
             p1, p2, _ = self.detector.calc_cartesian_positions(d1=d1, d2=d2)
             ax = self.fig.add_subplot(1, 1, 1,
@@ -306,11 +311,11 @@ class PeakPicker(object):
             ax.xaxis.label.set_color('blue')
             ax.tick_params(colors="blue", labelbottom='off', labeltop='on',
                            labelleft='off', labelright='on')
-#             ax.autoscale_view(False, False, False)
+            # ax.autoscale_view(False, False, False)
 
         else:
-            cbar = self.fig.colorbar(im, label=txt)
-#         self.ax.autoscale_view(False, False, False)
+            _cbar = self.fig.colorbar(im, label=txt)
+        # self.ax.autoscale_view(False, False, False)
         update_fig(self.fig)
         if maximize:
             maximize_fig(self.fig)
@@ -327,15 +332,15 @@ class PeakPicker(object):
     def display_points(self, minIndex=0, reset=False):
         """
         display all points and their ring annotations
-        @param minIndex: ring index to start with
-        @param reset: remove all point before re-displaying them
+        :param minIndex: ring index to start with
+        :param reset: remove all point before re-displaying them
         """
         if self.ax is not None:
             if reset:
                 self.ax.texts = []
                 self.ax.lines = []
 
-            for lbl, gpt in self.points._groups.items():
+            for _lbl, gpt in self.points._groups.items():
                 idx = gpt.ring
                 if idx < minIndex:
                     continue
@@ -352,7 +357,7 @@ class PeakPicker(object):
         """
         remove a group of points
 
-        @param lbl: label of the group of points
+        :param lbl: label of the group of points
         """
         gpt = self.points.pop(lbl=lbl)
         if gpt and self.ax:
@@ -371,9 +376,9 @@ class PeakPicker(object):
         def annontate(x, x0=None, idx=None, gpt=None):
             """
             Call back method to annotate the figure while calculation are going on ...
-            @param x: coordinates
-            @param x0: coordinates of the starting point
-            @param gpt: group of point, instance of PointGroup
+            :param x: coordinates
+            :param x0: coordinates of the starting point
+            :param gpt: group of point, instance of PointGroup
             TODO
             """
             if x0 is None:
@@ -395,8 +400,8 @@ class PeakPicker(object):
             """
             plot new set of points
 
-            @param points: list of points
-            @param gpt: : group of point, instance of PointGroup
+            :param points: list of points
+            :param gpt: : group of point, instance of PointGroup
             """
             if points:
                 if not gpt:
@@ -415,7 +420,7 @@ class PeakPicker(object):
             if points:
                 gpt = common_creation(points)
                 annontate(points[0], [event.ydata, event.xdata], gpt=gpt)
-                logger.info("Created group #%2s with %i points" % (gpt.label, len(gpt)))
+                logger.info("Created group #%2s with %i points", gpt.label, len(gpt))
             else:
                 logger.warning("No peak found !!!")
 
@@ -425,7 +430,7 @@ class PeakPicker(object):
             if newpeak:
                 gpt = common_creation([newpeak])
                 annontate(newpeak, [event.ydata, event.xdata], gpt=gpt)
-                logger.info("Create group #%2s with single point x=%5.1f, y=%5.1f" % (gpt.label, newpeak[1], newpeak[0]))
+                logger.info("Create group #%2s with single point x=%5.1f, y=%5.1f", gpt.label, newpeak[1], newpeak[0])
             else:
                 logger.warning("No peak found !!!")
 
@@ -446,7 +451,7 @@ class PeakPicker(object):
                                               self.massif_contour)
             if listpeak:
                 gpt.points += listpeak
-                logger.info("Added %i points to group #%2s (now %i points)" % (len(listpeak), len(gpt.label), len(gpt)))
+                logger.info("Added %i points to group #%2s (now %i points)", len(listpeak), len(gpt.label), len(gpt))
             else:
                 logger.warning("No peak found !!!")
             common_creation(gpt.points, gpt)
@@ -464,7 +469,7 @@ class PeakPicker(object):
             newpeak = self.massif.nearest_peak([event.ydata, event.xdata])
             if newpeak:
                 gpt.points.append(newpeak)
-                logger.info("x=%5.1f, y=%5.1f added to group #%2s" % (newpeak[1], newpeak[0], gpt.label))
+                logger.info("x=%5.1f, y=%5.1f added to group #%2s", newpeak[1], newpeak[0], gpt.label)
             else:
                 logger.warning("No peak found !!!")
             common_creation(gpt.points, gpt)
@@ -474,7 +479,7 @@ class PeakPicker(object):
             ring = self.spinbox.value()
             gpt = self.points.pop(ring)
             if not gpt:
-                logger.warning("No group of points for ring %s" % ring)
+                logger.warning("No group of points for ring %s", ring)
                 return
 #            print("Remove group from ring %s label %s" % (ring, gpt.label))
             if gpt.annotate:
@@ -484,7 +489,7 @@ class PeakPicker(object):
                 if gpt.plot[0] in self.ax.lines:
                     self.ax.lines.remove(gpt.plot[0])
             if len(gpt) > 0:
-                logger.info("Removing group #%2s containing %i points" % (gpt.label, len(gpt)))
+                logger.info("Removing group #%2s containing %i points", gpt.label, len(gpt))
             else:
                 logger.info("No groups to remove")
             update_fig(self.fig)
@@ -495,7 +500,7 @@ class PeakPicker(object):
             ring = self.spinbox.value()
             gpt = self.points.get(ring)
             if not gpt:
-                logger.warning("No group of points for ring %s" % ring)
+                logger.warning("No group of points for ring %s", ring)
                 return
 #            print("Remove 1 point from group from ring %s label %s" % (ring, gpt.label))
             if gpt.annotate:
@@ -512,14 +517,14 @@ class PeakPicker(object):
                 # index and distance of smallest distance:
                 indexMin = min(enumerate(distsq), key=operator.itemgetter(1))
                 removedPt = gpt.points.pop(indexMin[0])
-                logger.info("x=%5.1f, y=%5.1f removed from group #%2s (%i points left)" % (removedPt[1], removedPt[0], gpt.label, len(gpt)))
+                logger.info("x=%5.1f, y=%5.1f removed from group #%2s (%i points left)", removedPt[1], removedPt[0], gpt.label, len(gpt))
                 # annotate (new?) 1st point and add remaining points back
                 pt = (gpt.points[0][0], gpt.points[0][1])
                 gpt.annotate = annontate(pt, (pt[0] + 10, pt[1] + 10))
                 npl = numpy.array(gpt.points)
                 gpt.plot = self.ax.plot(npl[:, 1], npl[:, 0], "o", scalex=False, scaley=False)
             elif len(gpt) == 1:
-                logger.info("Removing group #%2s containing 1 point" % (gpt.label))
+                logger.info("Removing group #%2s containing 1 point", gpt.label)
                 gpt = self.points.pop(ring)
             else:
                 logger.info("No groups to remove")
@@ -527,7 +532,7 @@ class PeakPicker(object):
             sys.stdout.flush()
 
         with self._sem:
-            logger.debug("Button: %i, Key modifier: %s" % (event.button, event.key))
+            logger.debug("Button: %i, Key modifier: %s", event.button, event.key)
 
             if ((event.button == 3) and (event.key == 'shift')) or \
                ((event.button == 1) and (event.key == 'v')):
@@ -548,13 +553,13 @@ class PeakPicker(object):
             elif (event.button == 2) or (event.button == 1 and event.key == "d"):
                 erase_grp(event)
             else:
-                logger.info("Unknown combination: Button: %i, Key modifier: %s" % (event.button, event.key))
+                logger.info("Unknown combination: Button: %i, Key modifier: %s", event.button, event.key)
 
     def finish(self, filename=None, callback=None):
         """
         Ask the ring number for the given points
 
-        @param filename: file with the point coordinates saved
+        :param filename: file with the point coordinates saved
         """
         logging.info(os.linesep.join(self.help))
         if not callback:
@@ -582,7 +587,7 @@ class PeakPicker(object):
         """
         Overlay a contour-plot
 
-        @param data: 2darray with the 2theta values in radians...
+        :param data: 2darray with the 2theta values in radians...
         """
         if self.fig is None:
             logging.warning("No diffraction image available => not showing the contour")
@@ -622,7 +627,7 @@ class PeakPicker(object):
         """
         Overlays a mask over a diffraction image
 
-        @param data: mask to be overlaid
+        :param data: mask to be overlaid
         """
 
         if self.fig is None:
@@ -714,11 +719,11 @@ class ControlPoints(object):
                 elif os.path.isfile(calibrant):
                     self.calibrant = Calibrant(calibrant)
                 else:
-                    logger.error("Unable to handle such calibrant: %s" % calibrant)
+                    logger.error("Unable to handle such calibrant: %s", calibrant)
             elif isinstance(self.dSpacing, (numpy.ndarray, list, tuple, array)):
                 self.calibrant = Calibrant(dSpacing=list(calibrant))
             else:
-                logger.error("Unable to handle such calibrant: %s" % calibrant)
+                logger.error("Unable to handle such calibrant: %s", calibrant)
         if not self.calibrant.wavelength:
             self.calibrant.set_wavelength(wavelength)
 
@@ -753,11 +758,11 @@ class ControlPoints(object):
 
     def append(self, points, ring=None, annotate=None, plot=None):
         """
-        @param point: list of points
-        @param ring: ring number
-        @param annotate: matplotlib.annotate reference
-        @param plot: matplotlib.plot reference
-        @return: PointGroup instance
+        :param point: list of points
+        :param ring: ring number
+        :param annotate: matplotlib.annotate reference
+        :param plot: matplotlib.plot reference
+        :return: PointGroup instance
         """
         with self._sem:
             gpt = PointGroup(points, ring, annotate, plot)
@@ -766,8 +771,8 @@ class ControlPoints(object):
 
     def append_2theta_deg(self, points, angle=None, ring=None):
         """
-        @param point: list of points
-        @param angle: 2-theta angle in degrees
+        :param point: list of points
+        :param angle: 2-theta angle in degrees
         """
         if angle:
             self.append(points, numpy.deg2rad(angle), ring)
@@ -778,7 +783,7 @@ class ControlPoints(object):
         """
         retireves the last set of points for a given ring (by default the last)
 
-        @param ring: index of ring to search for
+        :param ring: index of ring to search for
         """
         out = None
         with self._sem:
@@ -793,21 +798,21 @@ class ControlPoints(object):
                 lst = [l for l, gpt in self._groups.items() if gpt.ring == ring]
                 lst.sort(key=lambda item: self._groups[item].code)
                 if not lst:
-                    logger.warning("No group for ring %s in ControlPoints.get" % (ring))
+                    logger.warning("No group for ring %s in ControlPoints.get", ring)
                     return
                 lbl = lst[-1]
             if lbl in self._groups:
                 out = self._groups.get(lbl)
             else:
-                logger.warning("No such group %s in ControlPoints.pop" % (lbl))
+                logger.warning("No such group %s in ControlPoints.pop", lbl)
         return out
 
     def pop(self, ring=None, lbl=None):
         """
         Remove the set of points, either from its code or from a given ring (by default the last)
 
-        @param ring: index of ring of which remove the last group
-        @param lbl: code of the ring to remove
+        :param ring: index of ring of which remove the last group
+        :param lbl: code of the ring to remove
         """
         out = None
         with self._sem:
@@ -823,20 +828,20 @@ class ControlPoints(object):
                     lst = [l for l, gpt in self._groups.items() if gpt.ring == ring]
                     lst.sort(key=lambda item: self._groups[item].code)
                     if not lst:
-                        logger.warning("No group for ring %s in ControlPoints.pop" % (ring))
+                        logger.warning("No group for ring %s in ControlPoints.pop", ring)
                         return
                     lbl = lst[-1]
             if lbl in self._groups:
                 out = self._groups.pop(lbl)
             else:
-                logger.warning("No such group %s in ControlPoints.pop" % (lbl))
+                logger.warning("No such group %s in ControlPoints.pop", lbl)
         return out
 
     def save(self, filename):
         """
         Save a set of control points to a file
-        @param filename: name of the file
-        @return: None
+        :param filename: name of the file
+        :return: None
         """
         self.check()
         with self._sem:
@@ -925,7 +930,7 @@ class ControlPoints(object):
                             x = float(vx)
                             y = float(vy)
                         except Exception as error:
-                            logger.error("ControlPoints.load: unable to convert to float %s (point)", value, error)
+                            logger.error("ControlPoints.load: unable to convert to float %s (point): %s", value, error)
                         else:
                             points.append([y, x])
                 elif key.startswith("new"):
@@ -978,8 +983,8 @@ class ControlPoints(object):
     def getWeightedList(self, image):
         """
         Retrieve the list of control points suitable for geometry refinement with ring number and intensities
-        @param image:
-        @return: a (x,4) array with pos0, pos1, ring nr and intensity
+        :param image:
+        :return: a (x,4) array with pos0, pos1, ring nr and intensity
 
         #TODO: refine the value of the intensity using 2nd order polynomia
         """
@@ -1018,7 +1023,7 @@ class ControlPoints(object):
                         gpt.ring = inputRing
                         bOk = True
                     else:
-                        logging.error("Invalid ring number %i (range 0 -> %2i)" % (inputRing, len(self.calibrant.dSpacing) - 1))
+                        logging.error("Invalid ring number %i (range 0 -> %2i)", inputRing, len(self.calibrant.dSpacing) - 1)
 
     def setWavelength_change2th(self, value=None):
         with self._sem:
@@ -1102,11 +1107,11 @@ class PointGroup(object):
         """
         Constructor
 
-        @param points: list of points
-        @param ring: ring number
-        @param annotate: reference to the matplotlib annotate output
-        @param plot: reference to the matplotlib plot
-        @param force_label: allows to enforce the label
+        :param points: list of points
+        :param ring: ring number
+        :param annotate: reference to the matplotlib annotate output
+        :param plot: reference to the matplotlib plot
+        :param force_label: allows to enforce the label
         """
         if points:
             self.points = points
@@ -1136,7 +1141,7 @@ class PointGroup(object):
 
     def set_ring(self, value):
         if type(value) != int:
-            logger.error("Ring: %s" % value)
+            logger.error("Ring: %s", value)
             import traceback
             traceback.print_stack()
             self._ring = int(value)
