@@ -1,39 +1,36 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-#    Project: Fast Azimuthal integration
-#             https://github.com/pyFAI/pyFAI
+#    Project: Azimuthal integration
+#             https://github.com/silx-kit/pyFAI
 #
-#    Copyright (C) European Synchrotron Radiation Facility, Grenoble, France
+#    Copyright (C) 2015-2016 European Synchrotron Radiation Facility, Grenoble, France
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
 #
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
 
-from __future__ import with_statement, print_function
-
-__author__ = "Jerome Kieffer"
-__contact__ = "Jerome.Kieffer@ESRF.eu"
-__license__ = "GPLv3+"
-__copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "02/05/2016"
-__status__ = "development"
-__doc__ = """This module contains the Worker class:
+"""This module contains the Worker class:
 
 A tool able to perform azimuthal integration with:
 additional saving capabilities like
+
 - save as 2/3D structure in a HDF5 File
 - read from HDF5 files
 
@@ -41,75 +38,90 @@ Aims at being integrated into a plugin like LImA or as model for the GUI
 
 The configuration of this class is mainly done via a dictionary transmitted as a JSON string:
 Here are the valid keys:
-    "dist",
-    "poni1",
-    "poni2",
-    "rot1"
-    "rot3"
-    "rot2"
-    "pixel1"
-    "pixel2"
-
-    "splineFile"
-    "wavelength"
-
-    "poni" #path of the file
-
-    "chi_discontinuity_at_0"
-    "do_mask"
-    "do_dark"
-    "do_azimuthal_range"
-    "do_flat"
-    "do_2D"
-    "azimuth_range_min"
-    "azimuth_range_max"
-
-    "polarization_factor"
-    "nbpt_rad"
-    "do_solid_angle"
-    "do_radial_range"
-    "do_poisson"
-    "delta_dummy"
-    "nbpt_azim"
-    "flat_field"
-    "radial_range_min"
-    "dark_current"
-    "do_polarization"
-    "mask_file"
-    "detector"
-    "unit"
-    "radial_range_max"
-    "val_dummy"
-    "do_dummy"
-    "method"
-}
 
+- "dist"
+- "poni1"
+- "poni2"
+- "rot1"
+- "rot3"
+- "rot2"
+- "pixel1"
+- "pixel2"
+- "splineFile"
+- "wavelength"
+- "poni" #path of the file
+- "chi_discontinuity_at_0"
+- "do_mask"
+- "do_dark"
+- "do_azimuthal_range"
+- "do_flat"
+- "do_2D"
+- "azimuth_range_min"
+- "azimuth_range_max"
+- "polarization_factor"
+- "nbpt_rad"
+- "do_solid_angle"
+- "do_radial_range"
+- "do_poisson"
+- "delta_dummy"
+- "nbpt_azim"
+- "flat_field"
+- "radial_range_min"
+- "dark_current"
+- "do_polarization"
+- "mask_file"
+- "detector"
+- "unit"
+- "radial_range_max"
+- "val_dummy"
+- "do_dummy"
+- "method"
 """
 
+
+from __future__ import with_statement, print_function, division
+
+__author__ = "Jerome Kieffer"
+__contact__ = "Jerome.Kieffer@ESRF.eu"
+__license__ = "MIT"
+__copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
+__date__ = "24/11/2016"
+__status__ = "development"
+
 import threading
 import os.path
 import logging
+import json
+
 logger = logging.getLogger("pyFAI.worker")
+
 import numpy
 import fabio
 from .detectors import detector_factory
 from .azimuthalIntegrator import AzimuthalIntegrator
 from .distortion import Distortion
 from . import units
-import json
+try:
+    from .ext.preproc import preproc
+except ImportError as err:
+    logger.warning("Unable to import preproc: %s", err)
+    preproc = None
 # from .io import h5py, HDF5Writer
 
 
 def make_ai(config):
     """Create an Azimuthal integrator from the configuration
-    Static method !
+    stand alone function !
 
-    @param config: dict with all parameters
-    @return: configured (but uninitialized) AzimuthalIntgrator
+    :param config: dict with all parameters
+    :return: configured (but uninitialized) AzimuthalIntgrator
     """
     poni = config.get("poni")
     if poni and os.path.isfile(poni):
         ai = AzimuthalIntegrator.sload(poni)
+    else:
+        ai = AzimuthalIntegrator()
+
     detector = config.get("detector", None)
     if detector:
         ai.detector = detector_factory(detector)
@@ -117,7 +129,7 @@ def make_ai(config):
     wavelength = config.get("wavelength", 0)
     if wavelength:
         if wavelength <= 0 or wavelength > 1e-6:
-            logger.warning("Wavelength is in meter ... unlikely value %s" % wavelength)
+            logger.warning("Wavelength is in meter ... unlikely value %s", wavelength)
         ai.wavelength = wavelength
 
     splinefile = config.get("splineFile")
@@ -137,7 +149,7 @@ def make_ai(config):
             try:
                 mask = fabio.open(mask_file).data
             except Exception as error:
-                logger.error("Unable to load mask file %s, error %s" % (mask_file, error))
+                logger.error("Unable to load mask file %s, error %s", mask_file, error)
             else:
                 ai.mask = mask
 
@@ -155,20 +167,27 @@ def make_ai(config):
 
 
 class Worker(object):
-    def __init__(self, azimuthalIntgrator=None,
+    def __init__(self, azimuthalIntegrator=None,
                  shapeIn=(2048, 2048), shapeOut=(360, 500),
-                 unit="r_mm", dummy=None, delta_dummy=None):
+                 unit="r_mm", dummy=None, delta_dummy=None,
+                 azimuthalIntgrator=None):
         """
-        @param azimuthalIntgrator: pyFAI.AzimuthalIntegrator instance
-        @param shapeIn: image size in input
-        @param shapeOut: Integrated size: can be (1,2000) for 1D integration
-        @param unit: can be "2th_deg, r_mm or q_nm^-1 ...
+        :param azimuthalIntegrator AzimuthalIntegrator: pyFAI.AzimuthalIntegrator instance
+        :param azimuthalIntgrator AzimuthalIntegrator: pyFAI.AzimuthalIntegrator instance (deprecated)
+        :param shapeIn: image size in input
+        :param shapeOut: Integrated size: can be (1,2000) for 1D integration
+        :param unit: can be "2th_deg, r_mm or q_nm^-1 ...
         """
+        # TODO remove it in few month (added on 2016-08-04)
+        if azimuthalIntgrator is not None:
+            logger.warning("'Worker(azimuthalIntgrator=...)' parameter is deprecated cause it contains a typo. Please use 'azimuthalIntegrator='")
+            azimuthalIntegrator = azimuthalIntgrator
+
         self._sem = threading.Semaphore()
-        if azimuthalIntgrator is None:
+        if azimuthalIntegrator is None:
             self.ai = AzimuthalIntegrator()
         else:
-            self.ai = azimuthalIntgrator
+            self.ai = azimuthalIntegrator
 #        self.config = {}
 #        self.config_file = "azimInt.json"
 #        self.nbpt_azim = 0
@@ -185,7 +204,7 @@ class Worker(object):
         self._normalization_factor = None  # Value of the monitor: divides the intensity by this value for normalization
         self.nbpt_azim, self.nbpt_rad = shapeOut
         self._unit = units.to_unit(unit)
-        self.polarization = None
+        self.polarization_factor = None
         self.dummy = dummy
         self.delta_dummy = delta_dummy
         self.correct_solid_angle = True
@@ -213,9 +232,9 @@ class Worker(object):
                   "Input image shape: %s" % list(self.shape),
                   "Number of points in radial direction: %s" % self.nbpt_rad,
                   "Number of points in azimuthal direction: %s" % self.nbpt_azim,
-                  "Unit in radial dimension: %s" % self.unit.REPR,
+                  "Unit in radial dimension: %s" % self.unit,
                   "Correct for solid angle: %s" % self.correct_solid_angle,
-                  "Polarization factor: %s" % self.polarization,
+                  "Polarization factor: %s" % self.polarization_factor,
                   "Dark current image: %s" % self.dark_current_image,
                   "Flat field image: %s" % self.flat_field_image,
                   "Mask image: %s" % self.mask_image,
@@ -243,29 +262,30 @@ class Worker(object):
         """
         This is just to force the integrator to initialize with a given input image shape
 
-        @param shape: shape of the input image
-        @param sync: return only when synchronized
+        :param shape: shape of the input image
+        :param sync: return only when synchronized
         """
         self.shape = shape
         self.ai.reset()
         self.warmup(sync)
 
-    def process(self, data):
+    def process(self, data, normalization_factor=1.0, writer=None):
         """
         Process a frame
         #TODO:
         dark, flat, sa are missing
 
-        @param: data: numpy array containing the input image
+        :param data: numpy array containing the input image
+        :param writer: An open writer in which 'write' will be called with the result of the integration
         """
 
         with self._sem:
-            monitor = self._normalization_factor
+            monitor = self._normalization_factor * normalization_factor if self._normalization_factor else normalization_factor
         kwarg = {"unit": self.unit,
                  "dummy": self.dummy,
                  "delta_dummy": self.delta_dummy,
                  "method": self.method,
-                 "polarization_factor":self.polarization,
+                 "polarization_factor": self.polarization_factor,
                  # "filename": None,
                  "safe": self.is_safe,
                  "data": data,
@@ -303,12 +323,15 @@ class Worker(object):
 
         try:
             if self.do_2D():
-                rData, self.radial, self.azimuthal = self.ai.integrate2d(**kwarg)
+                integrated_result = self.ai.integrate2d(**kwarg)
+                self.radial = integrated_result.radial
+                self.azimuthal = integrated_result.azimuthal
+                result = integrated_result.intensity
             else:
-                rData = self.ai.integrate1d(**kwarg)
-                self.radial = rData[0]
+                integrated_result = self.ai.integrate1d(**kwarg)
+                self.radial = integrated_result.radial
                 self.azimuthal = None
-                rData = numpy.vstack(rData).T
+                result = numpy.vstack(integrated_result).T
 
         except Exception as err:
             err2 = ["error in integration",
@@ -321,11 +344,14 @@ class Worker(object):
                     # str(self.ai._csr_integrator),
                     # "csr size: %s" % self.ai._lut_integrator.size
                     ]
-            logger.error(err2)
+            logger.error("; ".join(err2))
             raise err
 
+        if writer is not None:
+            writer.write(integrated_result)
+
         if self.output == "numpy":
-            return rData
+            return result
 
     def setSubdir(self, path):
         """
@@ -369,10 +395,10 @@ class Worker(object):
             try:
                 fwavelength = float(wavelength)
             except ValueError:
-                logger.error("Unable to convert wavelength to float: %s" % wavelength)
+                logger.error("Unable to convert wavelength to float: %s", wavelength)
             else:
                 if fwavelength <= 0 or fwavelength > 1e-6:
-                    logger.warning("Wavelength is in meter ... unlikely value %s" % fwavelength)
+                    logger.warning("Wavelength is in meter ... unlikely value %s", fwavelength)
                 self.ai.wavelength = fwavelength
 
         splineFile = config.get("splineFile")
@@ -398,7 +424,7 @@ class Worker(object):
             try:
                 mask = fabio.open(mask_file).data
             except Exception as error:
-                logger.error("Unable to load mask file %s, error %s" % (mask_file, error))
+                logger.error("Unable to load mask file %s, error %s", mask_file, error)
             else:
                 self.ai.mask = mask
                 self.mask_image = os.path.abspath(mask_file)
@@ -418,9 +444,9 @@ class Worker(object):
         self.unit = units.to_unit(config.get("unit", units.TTH_DEG))
         self.do_poisson = config.get("do_poisson")
         if config.get("do_polarization"):
-            self.polarization = config.get("polarization")
+            self.polarization_factor = config.get("polarization_factor")
         else:
-            self.polarization = None
+            self.polarization_factor = None
         logger.info(self.ai.__repr__())
         self.reset()
         # For now we do not calculate the LUT as the size of the input image is unknown
@@ -430,6 +456,7 @@ class Worker(object):
 
     def get_unit(self):
         return self._unit
+
     unit = property(get_unit, set_unit)
 
     def set_error_model(self, value):
@@ -454,7 +481,7 @@ class Worker(object):
                 config[key] = self.ai.__getattribute__(key)
             except:
                 pass
-        for key in ["nbpt_azim", "nbpt_rad", "polarization", "dummy", "delta_dummy",
+        for key in ["nbpt_azim", "nbpt_rad", "polarization_factor", "dummy", "delta_dummy",
                     "correct_solid_angle", "dark_current_image", "flat_field_image",
                     "mask_image", "do_poisson", "shape", "method"]:
             try:
@@ -507,7 +534,7 @@ class Worker(object):
         """
         Process a dummy image to ensure everything is initialized
 
-        @param sync: wait for processing to be finished
+        :param sync: wait for processing to be finished
 
         """
         t = threading.Thread(target=self.process,
@@ -533,8 +560,13 @@ class PixelwiseWorker(object):
     """
     def __init__(self, dark=None, flat=None, solidangle=None, polarization=None,
                  mask=None, dummy=None, delta_dummy=None, device=None):
-        """
-        @param device: Used to influance OpenCL behavour: can be "cpu", "GPU", "Acc" or even an OpenCL context
+        """Constructor of the worker
+        
+        :param dark: array 
+        :param flat: array
+        :param solidangle: solid-angle array
+        :param polarization: numpy array with 2D polarization corrections
+        :param device: Used to influance OpenCL behavour: can be "cpu", "GPU", "Acc" or even an OpenCL context
         """
         self.ctx = None
         if dark is not None:
@@ -557,48 +589,59 @@ class PixelwiseWorker(object):
         if mask is None:
             self.mask = False
         elif mask.min() < 0 and mask.max() == 0:  # 0 is valid, <0 is invalid
-            self.mask = (mask < 0)
+            self.mask = (mask < 0).astype(numpy.int8)
         else:
-            self.mask = mask.astype(bool)
+            self.mask = mask.astype(numpy.int8)
 
         self.dummy = dummy
         self.delta_dummy = delta_dummy
         if device is not None:
             logger.warning("GPU is not yet implemented")
 
-    def process(self, data, normalization=None):
+    def process(self, data, normalization_factor=None):
         """
         Process the data and apply a normalization factor
-        @param data: input data
-        @param normalization: normalization factor
-        @return processed data
+        :param data: input data
+        :param normalization: normalization factor
+        :return processed data
         """
-        _shape = data.shape
-        #        ^^^^   this is why data is mandatory !
-        if self.dummy is not None:
-            if self.delta_dummy is None:
-                self.mask = numpy.logical_or((data == self.dummy), self.mask)
-            else:
-                self.mask = numpy.logical_or(abs(data - self.dummy) <= self.delta_dummy,
-                                             self.mask)
-            do_mask = True
+        if preproc is not None:
+            proc_data = preproc(data,
+                                dark=self.dark,
+                                flat=self.flat,
+                                solidangle=self.solidangle,
+                                polarization=self.polarization,
+                                absorption=None,
+                                mask=self.mask,
+                                dummy=self.dummy,
+                                delta_dummy=self.delta_dummy,
+                                normalization_factor=normalization_factor,
+                                empty=None)
         else:
-            do_mask = (self.mask is not False)
-        # Explicitly make an copy !
-        data = numpy.array(data, dtype=numpy.float32)
-        if self.dark is not None:
-            data -= self.dark
-        if self.flat is not None:
-            data /= self.flat
-        if self.solidangle is not None:
-            data /= self.solidangle
-        if self.polarization is not None:
-            data /= self.polarization
-        if normalization is not None:
-            data /= normalization
-        if do_mask:
-            data[self.mask] = self.dummy or 0
-        return data
+            if self.dummy is not None:
+                if self.delta_dummy is None:
+                    self.mask = numpy.logical_or((data == self.dummy), self.mask)
+                else:
+                    self.mask = numpy.logical_or(abs(data - self.dummy) <= self.delta_dummy,
+                                                 self.mask)
+                do_mask = True
+            else:
+                do_mask = (self.mask is not False)
+            # Explicitly make an copy !
+            proc_data = numpy.array(data, dtype=numpy.float32)
+            if self.dark is not None:
+                proc_data -= self.dark
+            if self.flat is not None:
+                proc_data /= self.flat
+            if self.solidangle is not None:
+                proc_data /= self.solidangle
+            if self.polarization is not None:
+                proc_data /= self.polarization
+            if normalization_factor is not None:
+                proc_data /= normalization_factor
+            if do_mask:
+                proc_data[self.mask] = self.dummy or 0
+        return proc_data
 
 
 class DistortionWorker(object):
@@ -607,8 +650,13 @@ class DistortionWorker(object):
     """
     def __init__(self, detector=None, dark=None, flat=None, solidangle=None, polarization=None,
                  mask=None, dummy=None, delta_dummy=None, device=None):
-        """
-        @param device: Used to influance OpenCL behavour: can be "cpu", "GPU", "Acc" or even an OpenCL context
+        """Constructor of the worker
+        :param dark: array 
+        :param flat: array
+        :param solidangle: solid-angle array
+        :param polarization: numpy array with 2D polarization corrections
+        :param device: Used to influance OpenCL behavour: can be "cpu", "GPU", "Acc" or even an OpenCL context
+        
         """
 
         self.ctx = None
@@ -629,11 +677,6 @@ class DistortionWorker(object):
         else:
             self.polarization = None
 
-        if detector is None:
-            self.distortion = None
-        else:
-            self.distortion = Distortion(detector, method="CSR", device=device)
-
         if mask is None:
             self.mask = False
         elif mask.min() < 0 and mask.max() == 0:  # 0 is valid, <0 is invalid
@@ -646,41 +689,57 @@ class DistortionWorker(object):
         if device is not None:
             logger.warning("GPU is not yet implemented")
 
-    def process(self, data, normalization=None):
+        if detector is None:
+            self.distortion = None
+        else:
+            self.distortion = Distortion(detector, method="LUT", device=device,
+                                         mask=self.mask, empty=self.dummy or 0)
+
+    def process(self, data, normalization_factor=1.0):
         """
         Process the data and apply a normalization factor
-        @param data: input data
-        @param normalization: normalization factor
-        @return processed data
+        :param data: input data
+        :param normalization: normalization factor
+        :return processed data
         """
-        _shape = data.shape
-        #        ^^^^   this is why data is mandatory !
-        if self.dummy is not None:
-            if self.delta_dummy is None:
-                self.mask = numpy.logical_or((data == self.dummy), self.mask)
-            else:
-                self.mask = numpy.logical_or(abs(data - self.dummy) <= self.delta_dummy,
-                                        self.mask)
-            do_mask = True
+        if preproc is not None:
+            proc_data = preproc(data,
+                                dark=self.dark,
+                                flat=self.flat,
+                                solidangle=self.solidangle,
+                                polarization=self.polarization,
+                                absorption=None,
+                                mask=self.mask,
+                                dummy=self.dummy,
+                                delta_dummy=self.delta_dummy,
+                                normalization_factor=normalization_factor,
+                                empty=None)
         else:
-            do_mask = (self.mask is not False)
-        # Explicitly make an copy !
-        data = numpy.array(data, dtype=numpy.float32)
-        if self.dark is not None:
-            data -= self.dark
-        if self.flat is not None:
-            data /= self.flat
-        if self.solidangle is not None:
-            data /= self.solidangle
-        if self.polarization is not None:
-            data /= self.polarization
+            if self.dummy is not None:
+                if self.delta_dummy is None:
+                    self.mask = numpy.logical_or((data == self.dummy), self.mask)
+                else:
+                    self.mask = numpy.logical_or(abs(data - self.dummy) <= self.delta_dummy,
+                                                 self.mask)
+                do_mask = True
+            else:
+                do_mask = (self.mask is not False)
+            # Explicitly make an copy !
+            proc_data = numpy.array(data, dtype=numpy.float32)
+            if self.dark is not None:
+                proc_data -= self.dark
+            if self.flat is not None:
+                proc_data /= self.flat
+            if self.solidangle is not None:
+                proc_data /= self.solidangle
+            if self.polarization is not None:
+                proc_data /= self.polarization
+            if normalization_factor is not None:
+                proc_data /= normalization_factor
+            if do_mask:
+                proc_data[self.mask] = self.dummy or 0
 
-        if do_mask:
-            data[self.mask] = self.dummy or 0
         if self.distortion is not None:
-            return self.distortion.correct(data)
+            return self.distortion.correct(proc_data, self.dummy, self.delta_dummy)
         else:
             return data
-
-
-
